@@ -6,22 +6,28 @@ This module contains a collection of utility classes and functions used in
 agate.
 """
 
-from collections import OrderedDict, Sequence
-from functools import wraps
+from collections import OrderedDict
+
+try:
+    from collections.abc import Sequence
+except ImportError:
+    from collections import Sequence
+
 import math
 import string
-import warnings
+from functools import wraps
+
 from slugify import slugify as pslugify
+
 from agate.warns import warn_duplicate_column, warn_unnamed_column
 
 try:
-    from cdecimal import Decimal, ROUND_FLOOR, ROUND_CEILING, getcontext
+    from cdecimal import ROUND_CEILING, ROUND_FLOOR, Decimal, getcontext
 except ImportError:  # pragma: no cover
     from decimal import Decimal, ROUND_FLOOR, ROUND_CEILING, getcontext
 
 import six
 
-
 #: Sentinal for use when `None` is an valid argument value
 default = object()
 
@@ -80,6 +86,9 @@ class Quantiles(Sequence):
     def __repr__(self):
         return repr(self._quantiles)
 
+    def __eq__(self, other):
+        return self._quantiles == other._quantiles
+
     def locate(self, value):
         """
         Identify which quantile a given value is part of.
@@ -133,7 +142,7 @@ def max_precision(values):
     precision = getcontext().prec
 
     for value in values:
-        if value is None or math.isnan(value):
+        if value is None or math.isnan(value) or math.isinf(value):
             continue
 
         sign, digits, exponent = value.normalize().as_tuple()
