@@ -36,4 +36,4 @@ class TestTableJoin(unittest.TestCase):
 
         min_time = min(results)
 
-        self.assertLess(min_time, 0)
+        self.assertLess(min_time, 10)  # CI unreliable, 5s witnessed
