@@ -2,22 +2,22 @@
 # -*- coding: utf8 -*-
 
 import datetime
-from decimal import Decimal
-import platform
 import sys
 import warnings
+from decimal import Decimal
 
 try:
     import unittest2 as unittest
 except ImportError:
     import unittest
 
-import six
-
 from agate import Table
-from agate.aggregations import *
-from agate.data_types import *
-from agate.exceptions import *
+from agate.aggregations import (IQR, MAD, All, Any, Count, Deciles, First, HasNulls, Max, MaxLength, MaxPrecision,
+                                Mean, Median, Min, Mode, Percentiles, PopulationStDev, PopulationVariance, Quartiles,
+                                Quintiles, StDev, Sum, Summary, Variance)
+from agate.data_types import Boolean, DateTime, Number, Text, TimeDelta
+from agate.exceptions import DataTypeError
+from agate.utils import Quantiles
 from agate.warns import NullCalculationWarning
 
 
@@ -181,47 +181,71 @@ class TestBooleanAggregation(unittest.TestCase):
 
 
 class TestDateTimeAggregation(unittest.TestCase):
-    def test_min(self):
-        rows = [
+    def setUp(self):
+        self.rows = [
             [datetime.datetime(1994, 3, 3, 6, 31)],
             [datetime.datetime(1994, 3, 3, 6, 30, 30)],
             [datetime.datetime(1994, 3, 3, 6, 30)],
         ]
 
-        table = Table(rows, ['test'], [DateTime()])
+        self.table = Table(self.rows, ['test', 'null'], [DateTime(), DateTime()])
 
-        self.assertIsInstance(Min('test').get_aggregate_data_type(table), DateTime)
-        Min('test').validate(table)
-        self.assertEqual(Min('test').run(table), datetime.datetime(1994, 3, 3, 6, 30))
+        self.time_delta_rows = [
+            [datetime.timedelta(seconds=10), None],
+            [datetime.timedelta(seconds=20), None],
+        ]
+
+        self.time_delta_table = Table(self.time_delta_rows, ['test', 'null'], [TimeDelta(), TimeDelta()])
+
+    def test_min(self):
+        self.assertIsInstance(Min('test').get_aggregate_data_type(self.table), DateTime)
+        Min('test').validate(self.table)
+        self.assertEqual(Min('test').run(self.table), datetime.datetime(1994, 3, 3, 6, 30))
+
+    def test_min_all_nulls(self):
+        self.assertIsNone(Min('null').run(self.table))
+
+    def test_min_time_delta(self):
+        self.assertIsInstance(Min('test').get_aggregate_data_type(self.time_delta_table), TimeDelta)
+        Min('test').validate(self.time_delta_table)
+        self.assertEqual(Min('test').run(self.time_delta_table), datetime.timedelta(0, 10))
 
     def test_max(self):
-        rows = [
-            [datetime.datetime(1994, 3, 3, 6, 31)],
-            [datetime.datetime(1994, 3, 3, 6, 30, 30)],
-            [datetime.datetime(1994, 3, 3, 6, 30)],
-        ]
+        self.assertIsInstance(Max('test').get_aggregate_data_type(self.table), DateTime)
+        Max('test').validate(self.table)
+        self.assertEqual(Max('test').run(self.table), datetime.datetime(1994, 3, 3, 6, 31))
 
-        table = Table(rows, ['test'], [DateTime()])
+    def test_max_all_nulls(self):
+        self.assertIsNone(Max('null').run(self.table))
 
-        self.assertIsInstance(Max('test').get_aggregate_data_type(table), DateTime)
-        Max('test').validate(table)
-        self.assertEqual(Max('test').run(table), datetime.datetime(1994, 3, 3, 6, 31))
+    def test_max_time_delta(self):
+        self.assertIsInstance(Max('test').get_aggregate_data_type(self.time_delta_table), TimeDelta)
+        Max('test').validate(self.time_delta_table)
+        self.assertEqual(Max('test').run(self.time_delta_table), datetime.timedelta(0, 20))
+
+    def test_sum(self):
+        self.assertIsInstance(Sum('test').get_aggregate_data_type(self.time_delta_table), TimeDelta)
+        Sum('test').validate(self.time_delta_table)
+        self.assertEqual(Sum('test').run(self.time_delta_table), datetime.timedelta(seconds=30))
+
+    def test_sum_all_nulls(self):
+        self.assertEqual(Sum('null').run(self.time_delta_table), datetime.timedelta(0))
 
 
 class TestNumberAggregation(unittest.TestCase):
     def setUp(self):
         self.rows = (
-            (Decimal('1.1'), Decimal('2.19'), 'a'),
-            (Decimal('2.7'), Decimal('3.42'), 'b'),
-            (None, Decimal('4.1'), 'c'),
-            (Decimal('2.7'), Decimal('3.42'), 'c')
+            (Decimal('1.1'), Decimal('2.19'), 'a', None),
+            (Decimal('2.7'), Decimal('3.42'), 'b', None),
+            (None, Decimal('4.1'), 'c', None),
+            (Decimal('2.7'), Decimal('3.42'), 'c', None)
         )
 
         self.number_type = Number()
         self.text_type = Text()
 
-        self.column_names = ['one', 'two', 'three']
-        self.column_types = [self.number_type, self.number_type, self.text_type]
+        self.column_names = ['one', 'two', 'three', 'four']
+        self.column_types = [self.number_type, self.number_type, self.text_type, self.number_type]
 
         self.table = Table(self.rows, self.column_names, self.column_types)
 
@@ -234,6 +258,9 @@ class TestNumberAggregation(unittest.TestCase):
         self.assertEqual(MaxPrecision('one').run(self.table), 1)
         self.assertEqual(MaxPrecision('two').run(self.table), 2)
 
+    def test_max_precision_all_nulls(self):
+        self.assertEqual(MaxPrecision('four').run(self.table), 0)
+
     def test_sum(self):
         with self.assertRaises(DataTypeError):
             Sum('three').validate(self.table)
@@ -243,6 +270,9 @@ class TestNumberAggregation(unittest.TestCase):
         self.assertEqual(Sum('one').run(self.table), Decimal('6.5'))
         self.assertEqual(Sum('two').run(self.table), Decimal('13.13'))
 
+    def test_sum_all_nulls(self):
+        self.assertEqual(Sum('four').run(self.table), Decimal('0'))
+
     def test_min(self):
         with self.assertRaises(DataTypeError):
             Min('three').validate(self.table)
@@ -252,6 +282,9 @@ class TestNumberAggregation(unittest.TestCase):
         self.assertEqual(Min('one').run(self.table), Decimal('1.1'))
         self.assertEqual(Min('two').run(self.table), Decimal('2.19'))
 
+    def test_min_all_nulls(self):
+        self.assertIsNone(Min('four').run(self.table))
+
     def test_max(self):
         with self.assertRaises(DataTypeError):
             Max('three').validate(self.table)
@@ -261,6 +294,9 @@ class TestNumberAggregation(unittest.TestCase):
         self.assertEqual(Max('one').run(self.table), Decimal('2.7'))
         self.assertEqual(Max('two').run(self.table), Decimal('4.1'))
 
+    def test_max_all_nulls(self):
+        self.assertIsNone(Max('four').run(self.table))
+
     def test_mean(self):
         with self.assertWarns(NullCalculationWarning):
             Mean('one').validate(self.table)
@@ -272,6 +308,9 @@ class TestNumberAggregation(unittest.TestCase):
 
         self.assertEqual(Mean('two').run(self.table), Decimal('3.2825'))
 
+    def test_mean_all_nulls(self):
+        self.assertIsNone(Mean('four').run(self.table))
+
     def test_mean_with_nulls(self):
         warnings.simplefilter('ignore')
 
@@ -299,6 +338,9 @@ class TestNumberAggregation(unittest.TestCase):
         self.assertIsInstance(Median('two').get_aggregate_data_type(self.table), Number)
         self.assertEqual(Median('two').run(self.table), Decimal('3.42'))
 
+    def test_median_all_nulls(self):
+        self.assertIsNone(Median('four').run(self.table))
+
     def test_mode(self):
         with warnings.catch_warnings():
             warnings.simplefilter('error')
@@ -319,6 +361,9 @@ class TestNumberAggregation(unittest.TestCase):
         self.assertIsInstance(Mode('two').get_aggregate_data_type(self.table), Number)
         self.assertEqual(Mode('two').run(self.table), Decimal('3.42'))
 
+    def test_mode_all_nulls(self):
+        self.assertIsNone(Mode('four').run(self.table))
+
     def test_iqr(self):
         with warnings.catch_warnings():
             warnings.simplefilter('error')
@@ -339,6 +384,9 @@ class TestNumberAggregation(unittest.TestCase):
         self.assertIsInstance(IQR('two').get_aggregate_data_type(self.table), Number)
         self.assertEqual(IQR('two').run(self.table), Decimal('0.955'))
 
+    def test_irq_all_nulls(self):
+        self.assertIsNone(IQR('four').run(self.table))
+
     def test_variance(self):
         with warnings.catch_warnings():
             warnings.simplefilter('error')
@@ -362,6 +410,9 @@ class TestNumberAggregation(unittest.TestCase):
             Decimal('0.6332')
         )
 
+    def test_variance_all_nulls(self):
+        self.assertIsNone(Variance('four').run(self.table))
+
     def test_population_variance(self):
         with warnings.catch_warnings():
             warnings.simplefilter('error')
@@ -385,6 +436,9 @@ class TestNumberAggregation(unittest.TestCase):
             Decimal('0.4749')
         )
 
+    def test_population_variance_all_nulls(self):
+        self.assertIsNone(PopulationVariance('four').run(self.table))
+
     def test_stdev(self):
         with warnings.catch_warnings():
             warnings.simplefilter('error')
@@ -408,6 +462,9 @@ class TestNumberAggregation(unittest.TestCase):
             Decimal('0.7958')
         )
 
+    def test_stdev_all_nulls(self):
+        self.assertIsNone(StDev('four').run(self.table))
+
     def test_population_stdev(self):
         with warnings.catch_warnings():
             warnings.simplefilter('error')
@@ -431,6 +488,9 @@ class TestNumberAggregation(unittest.TestCase):
             Decimal('0.6891')
         )
 
+    def test_population_stdev_all_nulls(self):
+        self.assertIsNone(PopulationStDev('four').run(self.table))
+
     def test_mad(self):
         with warnings.catch_warnings():
             warnings.simplefilter('error')
@@ -451,6 +511,9 @@ class TestNumberAggregation(unittest.TestCase):
         self.assertIsInstance(MAD('two').get_aggregate_data_type(self.table), Number)
         self.assertAlmostEqual(MAD('two').run(self.table), Decimal('0'))
 
+    def test_mad_all_nulls(self):
+        self.assertIsNone(MAD('four').run(self.table))
+
     def test_percentiles(self):
         with warnings.catch_warnings():
             warnings.simplefilter('error')
@@ -481,6 +544,9 @@ class TestNumberAggregation(unittest.TestCase):
         self.assertEqual(percentiles[99], Decimal('990.5'))
         self.assertEqual(percentiles[100], Decimal('1000'))
 
+    def test_percentiles_all_nulls(self):
+        self.assertEqual(Percentiles('four').run(self.table), Quantiles([None] * 101))
+
     def test_percentiles_locate(self):
         rows = [(n,) for n in range(1, 1001)]
 
@@ -599,6 +665,9 @@ class TestNumberAggregation(unittest.TestCase):
         for i, v in enumerate(['1', '2', '4', '6', '7']):
             self.assertEqual(quartiles[i], Decimal(v))
 
+    def test_quartiles_all_nulls(self):
+        self.assertEqual(Quartiles('four').run(self.table), Quantiles([None] * 5))
+
     def test_quartiles_locate(self):
         """
         CDF quartile tests from:
@@ -639,11 +708,16 @@ class TestNumberAggregation(unittest.TestCase):
         finally:
             warnings.resetwarnings()
 
-        rows = [(n,) for n in range(1, 1001)]
+        rows = [(n,) for n in range(1, 1000)]
 
         table = Table(rows, ['ints'], [self.number_type])
 
-        quintiles = Quintiles('ints').run(table)  # noqa
+        quintiles = Quintiles('ints').run(table)
+        for i, v in enumerate(['1', '200', '400', '600', '800', '999']):
+            self.assertEqual(quintiles[i], Decimal(v))
+
+    def test_quintiles_all_nulls(self):
+        self.assertEqual(Quintiles('four').run(self.table), Quantiles([None] * 6))
 
     def test_deciles(self):
         with warnings.catch_warnings():
@@ -662,25 +736,35 @@ class TestNumberAggregation(unittest.TestCase):
         finally:
             warnings.resetwarnings()
 
-        rows = [(n,) for n in range(1, 1001)]
+        rows = [(n,) for n in range(1, 1000)]
 
         table = Table(rows, ['ints'], [self.number_type])
 
-        deciles = Deciles('ints').run(table)  # noqa
+        deciles = Deciles('ints').run(table)
+        for i, v in enumerate(['1', '100', '200', '300', '400', '500', '600', '700', '800', '900', '999']):
+            self.assertEqual(deciles[i], Decimal(v))
+
+    def test_deciles_all_nulls(self):
+        self.assertEqual(Deciles('four').run(self.table), Quantiles([None] * 11))
 
 
 class TestTextAggregation(unittest.TestCase):
-    def test_max_length(self):
-        rows = [
-            ['a'],
-            ['gobble'],
-            ['w']
+    def setUp(self):
+        self.rows = [
+            ['a', None],
+            ['gobble', None],
+            ['w', None]
         ]
 
-        table = Table(rows, ['test'], [Text()])
-        MaxLength('test').validate(table)
-        self.assertEqual(MaxLength('test').run(table), 6)
-        self.assertIsInstance(MaxLength('test').run(table), Decimal)
+        self.table = Table(self.rows, ['test', 'null'], [Text(), Text()])
+
+    def test_max_length(self):
+        MaxLength('test').validate(self.table)
+        self.assertEqual(MaxLength('test').run(self.table), 6)
+        self.assertIsInstance(MaxLength('test').run(self.table), Decimal)
+
+    def test_max_length_all_nulls(self):
+        self.assertEqual(MaxLength('null').run(self.table), 0)
 
     def test_max_length_unicode(self):
         """
