@@ -2,19 +2,19 @@
 # -*- coding: utf8 -*-
 
 import datetime
-from decimal import Decimal
 import pickle
-import parsedatetime
+from decimal import Decimal
 
 try:
     import unittest2 as unittest
 except ImportError:
     import unittest
 
+import parsedatetime
 import pytz
+import six
 
-from agate.columns import *
-from agate.data_types import *
+from agate.data_types import Boolean, Date, DateTime, Number, Text, TimeDelta
 from agate.exceptions import CastError
 
 
@@ -124,7 +124,7 @@ class TestNumber(unittest.TestCase):
     def test_test(self):
         self.assertEqual(self.type.test(None), True)
         self.assertEqual(self.type.test('N/A'), True)
-        self.assertEqual(self.type.test(True), False)
+        self.assertEqual(self.type.test(True), True)
         self.assertEqual(self.type.test('True'), False)
         self.assertEqual(self.type.test(1), True)
         self.assertEqual(self.type.test(Decimal('1')), True)
@@ -149,22 +149,36 @@ class TestNumber(unittest.TestCase):
     def test_cast(self):
         values = (2, 1, None, Decimal('2.7'), 'n/a', '2.7', '200,000,000')
         casted = tuple(self.type.cast(v) for v in values)
-        self.assertSequenceEqual(casted, (Decimal('2'), Decimal('1'), None, Decimal('2.7'), None, Decimal('2.7'), Decimal('200000000')))
+        self.assertSequenceEqual(
+            casted,
+            (Decimal('2'), Decimal('1'), None, Decimal('2.7'), None, Decimal('2.7'), Decimal('200000000'))
+        )
 
     @unittest.skipIf(six.PY3, 'Not supported in Python 3.')
     def test_cast_long(self):
-        self.assertEqual(self.type.test(long('141414')), True)
-        self.assertEqual(self.type.cast(long('141414')), Decimal('141414'))
+        self.assertEqual(self.type.test(long('141414')), True)  # noqa: F821
+        self.assertEqual(self.type.cast(long('141414')), Decimal('141414'))  # noqa: F821
+
+    def test_boolean_cast(self):
+        values = (True, False)
+        casted = tuple(self.type.cast(v) for v in values)
+        self.assertSequenceEqual(casted, (Decimal('1'), Decimal('0')))
 
     def test_currency_cast(self):
         values = ('$2.70', '-$0.70', u'€14', u'50¢', u'-75¢', u'-$1,287')
         casted = tuple(self.type.cast(v) for v in values)
-        self.assertSequenceEqual(casted, (Decimal('2.7'), Decimal('-0.7'), Decimal('14'), Decimal('50'), Decimal('-75'), Decimal('-1287')))
+        self.assertSequenceEqual(
+            casted,
+            (Decimal('2.7'), Decimal('-0.7'), Decimal('14'), Decimal('50'), Decimal('-75'), Decimal('-1287'))
+        )
 
     def test_cast_locale(self):
         values = (2, 1, None, Decimal('2.7'), 'n/a', '2,7', '200.000.000')
-        casted = tuple(Number(locale='de_DE').cast(v) for v in values)
-        self.assertSequenceEqual(casted, (Decimal('2'), Decimal('1'), None, Decimal('2.7'), None, Decimal('2.7'), Decimal('200000000')))
+        casted = tuple(Number(locale='de_DE.UTF-8').cast(v) for v in values)
+        self.assertSequenceEqual(
+            casted,
+            (Decimal('2'), Decimal('1'), None, Decimal('2.7'), None, Decimal('2.7'), Decimal('200000000'))
+        )
 
     def test_cast_text(self):
         with self.assertRaises(CastError):
@@ -249,6 +263,34 @@ class TestDate(unittest.TestCase):
             None
         ))
 
+    def test_cast_format_locale(self):
+        date_type = Date(date_format='%d-%b-%Y', locale='de_DE.UTF-8')
+
+        # March can be abbreviated to Mrz or Mär depending on the locale version,
+        # so we use December in the first value to ensure the test passes everywhere
+        values = ('01-Dez-1994', '17-Feb-2011', None, '05-Jan-1984', 'n/a')
+        casted = tuple(date_type.cast(v) for v in values)
+        self.assertSequenceEqual(casted, (
+            datetime.date(1994, 12, 1),
+            datetime.date(2011, 2, 17),
+            None,
+            datetime.date(1984, 1, 5),
+            None
+        ))
+
+    def test_cast_locale(self):
+        date_type = Date(locale='fr_FR')
+
+        values = ('01 mars 1994', u'jeudi 17 février 2011', None, '5 janvier 1984', 'n/a')
+        casted = tuple(date_type.cast(v) for v in values)
+        self.assertSequenceEqual(casted, (
+            datetime.date(1994, 3, 1),
+            datetime.date(2011, 2, 17),
+            None,
+            datetime.date(1984, 1, 5),
+            None
+        ))
+
     def test_cast_error(self):
         with self.assertRaises(CastError):
             self.type.cast('quack')
@@ -256,7 +298,9 @@ class TestDate(unittest.TestCase):
     def test_pickle_parser(self):
         from_pickle = pickle.loads(pickle.dumps(self.type))
         self.assertEqual(from_pickle.date_format, self.type.date_format)
-        self.assertIsInstance(from_pickle.parser, parsedatetime.Calendar)
+        self.assertEqual(from_pickle.locale, self.type.locale)
+        self.assertIsInstance(from_pickle._constants, parsedatetime.Constants)
+        self.assertIsInstance(from_pickle._parser, parsedatetime.Calendar)
 
 
 class TestDateTime(unittest.TestCase):
@@ -333,11 +377,53 @@ class TestDateTime(unittest.TestCase):
     def test_cast_format(self):
         datetime_type = DateTime(datetime_format='%m-%d-%Y %I:%M %p')
 
-        values = ('03-01-1994 12:30 PM', '02-17-1011 06:30 AM', None, '01-05-1984 06:30 PM', 'n/a')
+        values = ('03-01-1994 12:30 PM', '02-17-2011 06:30 AM', None, '01-05-1984 06:30 PM', 'n/a')
         casted = tuple(datetime_type.cast(v) for v in values)
         self.assertSequenceEqual(casted, (
             datetime.datetime(1994, 3, 1, 12, 30, 0),
-            datetime.datetime(1011, 2, 17, 6, 30, 0),
+            datetime.datetime(2011, 2, 17, 6, 30, 0),
+            None,
+            datetime.datetime(1984, 1, 5, 18, 30, 0),
+            None
+        ))
+
+    def test_cast_format_locale(self):
+        date_type = DateTime(datetime_format='%Y-%m-%d %I:%M %p', locale='ko_KR.UTF-8')
+
+        # Date formats depend on the platform's strftime/strptime implementation;
+        # some platforms like macOS always return AM/PM for day periods (%p),
+        # so we will catch any CastError that may arise from the conversion
+        possible_values = (
+            ('1994-03-01 12:30 오후', '2011-02-17 06:30 오전', None, '1984-01-05 06:30 오후', 'n/a'),
+            ('1994-03-01 12:30 PM', '2011-02-17 06:30 AM', None, '1984-01-05 06:30 PM', 'n/a'),
+        )
+        valid = False
+        exceptions = []
+        for values in possible_values:
+            try:
+                casted = tuple(date_type.cast(v) for v in values)
+            except CastError as e:
+                exceptions.append(repr(e))
+                continue
+            self.assertSequenceEqual(casted, (
+                datetime.datetime(1994, 3, 1, 12, 30, 0),
+                datetime.datetime(2011, 2, 17, 6, 30, 0),
+                None,
+                datetime.datetime(1984, 1, 5, 18, 30, 0),
+                None
+            ))
+            valid = True
+        if not valid:
+            raise AssertionError('\n\n'.join(exceptions))
+
+    def test_cast_locale(self):
+        date_type = DateTime(locale='fr_FR')
+
+        values = ('01/03/1994 12:30', '17/2/11 6:30', None, '5/01/84 18:30', 'n/a')
+        casted = tuple(date_type.cast(v) for v in values)
+        self.assertSequenceEqual(casted, (
+            datetime.datetime(1994, 3, 1, 12, 30, 0),
+            datetime.datetime(2011, 2, 17, 6, 30, 0),
             None,
             datetime.datetime(1984, 1, 5, 18, 30, 0),
             None
@@ -351,7 +437,9 @@ class TestDateTime(unittest.TestCase):
         from_pickle = pickle.loads(pickle.dumps(self.type))
         self.assertEqual(from_pickle.datetime_format, self.type.datetime_format)
         self.assertEqual(from_pickle.timezone, self.type.timezone)
+        self.assertEqual(from_pickle.locale, self.type.locale)
         self.assertEqual(from_pickle._source_time, self.type._source_time)
+        self.assertIsInstance(from_pickle._constants, parsedatetime.Constants)
         self.assertIsInstance(from_pickle._parser, parsedatetime.Calendar)
 
 
